@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008, 2010 Zuza Software Foundation
 #
@@ -43,7 +42,7 @@ class QphUnit(lisa.LISAunit):
     rootNode = "phrase"
     languageNode = "source"
     textNode = ""
-    namespace = ''
+    namespace = ""
 
     def createlanguageNode(self, lang, text, purpose):
         """Returns an xml Element setup with given parameters."""
@@ -60,7 +59,9 @@ class QphUnit(lisa.LISAunit):
 
     def getlanguageNodes(self):
         """We override this to get source and target nodes."""
-        return [n for n in [self._getsourcenode(), self._gettargetnode()] if n is not None]
+        return [
+            n for n in [self._getsourcenode(), self._gettargetnode()] if n is not None
+        ]
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in a "definition" tag"""
@@ -70,9 +71,9 @@ class QphUnit(lisa.LISAunit):
         note.text = "\n".join(filter(None, [current_notes, text.strip()]))
 
     def getnotes(self, origin=None):
-        #TODO: consider only responding when origin has certain values
+        # TODO: consider only responding when origin has certain values
         notenode = self.xmlelement.find(self.namespaced("definition"))
-        comment = ''
+        comment = ""
         if notenode is not None:
             comment = notenode.text
         return comment
@@ -93,11 +94,11 @@ class QphFile(lisa.LISAfile):
     Extensions = ["qph"]
     rootNode = "QPH"
     bodyNode = "QPH"
-    XMLskeleton = '''<!DOCTYPE QPH>
+    XMLskeleton = """<!DOCTYPE QPH>
 <QPH>
 </QPH>
-'''
-    namespace = ''
+"""
+    namespace = ""
 
     def initbody(self):
         """Initialises self.body so it never needs to be retrieved from the XML
@@ -117,9 +118,9 @@ class QphFile(lisa.LISAfile):
         :return: ISO code e.g. af, fr, pt_BR
         :rtype: String
         """
-        lang = data.normalize_code(self.header.get('sourcelanguage', "en"))
-        if lang == 'en-us':
-            return 'en'
+        lang = data.normalize_code(self.header.get("sourcelanguage", "en"))
+        if lang == "en-us":
+            return "en"
         return lang
 
     def gettargetlanguage(self):
@@ -128,7 +129,7 @@ class QphFile(lisa.LISAfile):
         :return: ISO code e.g. af, fr, pt_BR
         :rtype: String
         """
-        return data.normalize_code(self.header.get('language'))
+        return data.normalize_code(self.header.get("language"))
 
     def settargetlanguage(self, targetlanguage):
         """Set the target language for this .qph file to *targetlanguage*.
@@ -137,7 +138,7 @@ class QphFile(lisa.LISAfile):
         :type targetlanguage: String
         """
         if targetlanguage:
-            self.header.set('language', targetlanguage)
+            self.header.set("language", targetlanguage)
 
     def serialize(self, out):
         """Write the XML document to the file `out`.
@@ -145,5 +146,6 @@ class QphFile(lisa.LISAfile):
         We have to override this to ensure mimic the Qt convention:
             - no XML declaration
         """
-        self.document.write(out, pretty_print=True, xml_declaration=False,
-                            encoding='utf-8')
+        self.document.write(
+            out, pretty_print=True, xml_declaration=False, encoding="utf-8"
+        )
